@@ -7,6 +7,7 @@ from typing import List, Optional
 import pandas as pd
 import requests
 from aiohttp import ClientSession
+from pydantic import Field
 
 from toucan_connectors.common import get_loop
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
@@ -44,23 +45,24 @@ def fetch_wootric_data(query, props_fetched=None, batch_size=5, max_pages=30):
     - `props_fetched`: if specified, a list of properties to pick in the json documents
       returned by wootric
 
-    - `batch_size`: number of requests to batch together. i.e. if `batch_size=5`, then the
-      API will be queried by batches of 5 queries until data is exhausted or `max_pages`
-      is reached.
+    - `batch_size`: number of documents fetched by request
 
     - `max_pages`: maximum number of pages to crawl.
     """
     all_data = []
-    for page in range(1, max_pages + 1, batch_size):
-        lastpage = min(page + batch_size, max_pages + 1)
-        urls = [f'{query}&page={pagenum}' for pagenum in range(page, lastpage)]
+    per_batch = 10
+    for page in range(1, max_pages + 1, per_batch):
+        page_to_crawl = max_pages if page + per_batch > max_pages else per_batch
+        urls = [
+            f'{query}&page={pagenum}&per_page={batch_size}'
+            for pagenum in range(1, page + page_to_crawl)
+        ]
         responses = batch_fetch(urls)
         data = chain.from_iterable(responses)
         if props_fetched is None:
             all_data.extend(data)
         else:
             all_data.extend([{prop: d[prop] for prop in props_fetched} for d in data])
-        # last response is empty, it means that wootric doesn't have any data left
         if not responses[-1]:
             break
     return all_data
@@ -99,8 +101,16 @@ def wootric_url(route):
 class WootricDataSource(ToucanDataSource):
     query: str
     properties: Optional[List[str]] = None
-    batch_size: int = 5
-    max_pages: int = 30
+    batch_size: int = Field(
+        5,
+        title='batch size',
+        description='Number of records returned on each page, max 50',
+        ge=1,
+        lte=50,
+    )
+    max_pages: int = Field(
+        10, titile='max pages', description='Number of returned page, max 30', ge=1, lte=30
+    )
 
 
 class WootricConnector(ToucanConnector):
